@@ -44,10 +44,10 @@
  * -----------------------------------------------------------------*/
 
 
-#define SUNDIALS_VERSION "7.1.1"
+#define SUNDIALS_VERSION "7.2.0"
 #define SUNDIALS_VERSION_MAJOR 7
-#define SUNDIALS_VERSION_MINOR 1
-#define SUNDIALS_VERSION_PATCH 1
+#define SUNDIALS_VERSION_MINOR 2
+#define SUNDIALS_VERSION_PATCH 0
 #define SUNDIALS_VERSION_LABEL ""
 #define SUNDIALS_GIT_VERSION ""
 
@@ -57,8 +57,8 @@
  * -----------------------------------------------------------------*/
 
 #define SUNDIALS_C_COMPILER_HAS_BUILTIN_EXPECT
-/* #undef SUNDIALS_C_COMPILER_HAS_ATTRIBUTE_ASSUME */
-#define SUNDIALS_C_COMPILER_HAS_BUILTIN_ASSUME
+#define SUNDIALS_C_COMPILER_HAS_ATTRIBUTE_ASSUME
+/* #undef SUNDIALS_C_COMPILER_HAS_BUILTIN_ASSUME */
 /* #undef SUNDIALS_C_COMPILER_HAS_ASSUME */
 #define SUNDIALS_C_COMPILER_HAS_ATTRIBUTE_UNUSED
 
@@ -77,12 +77,12 @@
  *     #define SUNDIALS_INT64_T 1
  *     #define SUNDIALS_INT32_T 1
  */
-#define SUNDIALS_INT32_T 1
+#define SUNDIALS_INT64_T 1
 
 /* Define the type of vector indices in SUNDIALS 'sunindextype'.
  * The macro will be defined with a type of the appropriate size.
  */
-#define SUNDIALS_INDEX_TYPE int32_t
+#define SUNDIALS_INDEX_TYPE int64_t
 
 /* Use POSIX timers if available.
  *     #define SUNDIALS_HAVE_POSIX_TIMERS
@@ -106,12 +106,12 @@
 
 /* Build metadata */
 #define SUN_C_COMPILER "Clang"
-#define SUN_C_COMPILER_VERSION "18.1.8"
-#define SUN_C_COMPILER_FLAGS "-O2 -pipe -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong"
+#define SUN_C_COMPILER_VERSION "19.1.4"
+#define SUN_C_COMPILER_FLAGS "-O2 -pipe -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong -Wp,-D__USE_MINGW_ANSI_STDIO=1 -Wno-return-type -Wno-deprecated-declarations"
 
 #define SUN_CXX_COMPILER "Clang"
-#define SUN_CXX_COMPILER_VERSION "18.1.8"
-#define SUN_CXX_COMPILER_FLAGS "-O2 -pipe -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong"
+#define SUN_CXX_COMPILER_VERSION "19.1.4"
+#define SUN_CXX_COMPILER_FLAGS "-O2 -pipe -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong -Wp,-D__USE_MINGW_ANSI_STDIO=1"
 
 #define SUN_FORTRAN_COMPILER ""
 #define SUN_FORTRAN_COMPILER_VERSION ""
@@ -119,8 +119,8 @@
 
 #define SUN_BUILD_TYPE "Release"
 
-#define SUN_JOB_ID "20240630192437"
-#define SUN_JOB_START_TIME "20240630192437"
+#define SUN_JOB_ID "20241213092736"
+#define SUN_JOB_START_TIME "20241213092736"
 
 #define SUN_TPL_LIST "OPENMP;KLU;BLAS_LAPACK;PTHREAD"
 #define SUN_TPL_LIST_SIZE ""
@@ -144,10 +144,13 @@
 /* HYPRE */
 /* #undef SUNDIALS_HYPRE_ENABLED */
 #define SUN_HYPRE_VERSION ""
+#define SUN_HYPRE_VERSION_MAJOR 
+#define SUN_HYPRE_VERSION_MINOR 
+#define SUN_HYPRE_VERSION_PATCH 
 
 /* KLU */
 #define SUNDIALS_KLU_ENABLED
-#define SUN_KLU_VERSION "2.3.3"
+#define SUN_KLU_VERSION "2.3.5"
 
 /* KOKKOS */
 /* #undef SUNDIALS_KOKKOS_ENABLED */
@@ -239,7 +242,7 @@
 /* #undef SUNDIALS_ONEMKL_USE_GETRS_LOOP */
 
 /* SUPERLUMT threading type */
-#define SUNDIALS_SUPERLUMT_THREAD_TYPE ""
+#define SUNDIALS_SUPERLUMT_THREAD_TYPE "PTHREAD"
 
 /* Trilinos with MPI is available, then
  *    #define SUNDIALS_TRILINOS_HAVE_MPI
